
#pragma BEGINDUMP


/*
   MINIGUI - Harbour Win32 GUI library source code

   Copyright 2002-2010 Roberto Lopez <harbourminigui@gmail.com>
   http://harbourminigui.googlepages.com/

   This    program  is  free  software;  you can redistribute it and/or modify
   it under  the  terms  of the GNU General Public License as published by the
   Free  Software   Foundation;  either  version 2 of the License, or (at your
   option) any later version.

   This   program   is   distributed  in  the hope that it will be useful, but
   WITHOUT    ANY    WARRANTY;    without   even   the   implied  warranty  of
   MERCHANTABILITY  or  FITNESS  FOR A PARTICULAR PURPOSE. See the GNU General
   Public License for more details.

   You   should  have  received a copy of the GNU General Public License along
   with   this   software;   see  the  file COPYING. If not, write to the Free
   Software   Foundation,   Inc.,   59  Temple  Place,  Suite  330, Boston, MA
   02111-1307 USA (or visit the web site http://www.gnu.org/).

   As   a   special  exception, you have permission for additional uses of the
   text  contained  in  this  release  of  Harbour Minigui.

   The   exception   is that,   if   you  link  the  Harbour  Minigui  library
   with  other    files   to  produce   an   executable,   this  does  not  by
   itself   cause  the   resulting   executable    to   be  covered by the GNU
   General  Public  License.  Your    use  of that   executable   is   in   no
   way  restricted on account of linking the Harbour-Minigui library code into
   it.

   Parts of this project are based upon:

    "Harbour GUI framework for Win32"
    Copyright 2001 Alexander S.Kresin <alex@kresin.ru>
    Copyright 2001 Antonio Linares <alinares@fivetech.com>
    www - https://harbour.github.io/

    "Harbour Project"
    Copyright 1999-2019, https://harbour.github.io/

    "WHAT32"
    Copyright 2002 AJ Wos <andrwos@aust1.net>

    "HWGUI"
    Copyright 2001-2018 Alexander S.Kresin <alex@kresin.ru>

   Parts  of  this  code  is contributed and used here under permission of his
   author: Copyright 2016-2017 (C) P.Chornyj <myorg63@mail.ru>
 */

#define _WIN32_IE      0x0501

#if ( defined( __MINGW32__ ) || defined( __XCC__ ) || defined( __POCC__ ) ) && ( _WIN32_WINNT < 0x0500 )
# define _WIN32_WINNT  0x0500
#endif

#include <mgdefs.h>

#include <commctrl.h>
#include "hbapiitm.h"
#include "hbvm.h"

#ifdef __XHARBOUR__
# include "thread.h"
# else
# include "hbwinuni.h"
# include "hbthread.h"
#endif /* __XHARBOUR__ */
#include "hbatomic.h"

#ifndef WC_STATIC
#define WC_STATIC         "Static"
#endif

#define DEFAULT_LISTENER  "EVENTS"
#define MAX_EVENTS        64

#if ( defined( __POCC__ ) && __POCC__ >= 900 )
#undef UNALIGNED
#define UNALIGNED
#endif /* UNALIGNED */

// extern functions
HINSTANCE      GetResources( void );
// extern variables
extern HWND g_hWndMain;
extern HACCEL g_hAccel;
// static variables
static PHB_DYNS g_ListenerDyns = NULL;
#ifdef __XHARBOUR__
static HB_CRITICAL_T s_lst_mtx;
# define HMG_LISTENER_LOCK    HB_CRITICAL_LOCK( s_lst_mtx );
# define HMG_LISTENER_UNLOCK  HB_CRITICAL_UNLOCK( s_lst_mtx );
# else
static HB_CRITICAL_NEW( s_lst_mtx );
# define HMG_LISTENER_LOCK    hb_threadEnterCriticalSection( &s_lst_mtx )
# define HMG_LISTENER_UNLOCK  hb_threadLeaveCriticalSection( &s_lst_mtx )
#endif /* __XHARBOUR__ */

HB_FUNC( GETGLOBALLISTENER )
{
   if( NULL != g_ListenerDyns )
      hb_retc( hb_dynsymName( g_ListenerDyns ) );
   else
      hb_retc_null();
}

HB_FUNC( SETGLOBALLISTENER )
{
   const char * pszNewName = hb_parc( 1 );

   if( pszNewName && hb_dynsymIsFunction( hb_dynsymGet( pszNewName ) ) )
   {
      HMG_LISTENER_LOCK;
      g_ListenerDyns = hb_dynsymGet( pszNewName ); hb_retl( HB_TRUE );
      HMG_LISTENER_UNLOCK;
   }
   else
      hb_retl( HB_FALSE );
}

HB_FUNC( RESETGLOBALLISTENER )
{
   HMG_LISTENER_LOCK;
   g_ListenerDyns = hb_dynsymGet( DEFAULT_LISTENER );
   HMG_LISTENER_UNLOCK;
}

HB_FUNC( MSC_VER )
{
#if defined( _MSC_VER )
   hb_retnl( _MSC_VER );
#else
   hb_retnl( 0 );
#endif
}

#include "mgver.h"

HB_FUNC( HMG_VERSION )
{
   char * pszVersion;

   pszVersion = ( char * ) hb_xgrab( 40 );
   hb_snprintf( pszVersion, 40, "Harbour MiniGUI %d.%d.%d (%s)",
                MG_VER_MAJOR, MG_VER_MINOR, MG_VER_RELEASE, MG_VER_STATUS );

   hb_retc_buffer( pszVersion );
}


#pragma ENDDUMP